@@ -265,12 +265,20 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return g723_3bit;
 	else if(!stricmp(name, "g723_40") || !stricmp(name, "g.723_40"))
 		return g723_5bit;
-	else if(!stricmp(name, ".al"))
+	else if(!stricmp(name, ".al") || !stricmp(name, ".alaw"))
 		return alawAudio;
-	else if(!stricmp(name, ".ul"))
+	else if(!stricmp(name, ".ul") || !stricmp(name, ".ulaw") || !stricmp(name, ".mulaw"))
 		return mulawAudio;
+	else if(!stricmp(name, ".sw") || !stricmp(name, ".raw") || !stricmp(name, ".pcm"))
+		return pcm16Mono;
+	else if(!stricmp(name, ".vox"))
+		return voxADPCM;
 	else if(!stricmp(name, ".adpcm"))
 		return g721ADPCM;
+	else if(!stricmp(name, ".a24"))
+		return g723_3bit;
+	else if(!stricmp(name, ".a40"))
+		return g723_5bit;
 	else if(!stricmp(name, ".cda"))
 		return cdaStereo;
 	else if(!stricmp(name, ".sx"))
@@ -319,6 +327,8 @@ const char *Audio::getMIME(Info &info)
 		return "audio/l16";
 	case voxADPCM:
 		return "audio/x-vox";
+	case gsmVoice:
+		return "audio/x-gsm";
 	default:
 		return NULL;
 	}
